@@ -17,8 +17,8 @@ package ODF::MailMerge;
 # ...but don't let CPAN or test harnes scanners see this as defining $VERSION
 { no strict 'refs'; ${__PACKAGE__."::VER"."SION"} = 999.999; }
 
-our $VERSION = '1.003'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
-our $DATE = '2023-09-20'; # DATE from Dist::Zilla::Plugin::OurDate
+our $VERSION = '1.004'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
+our $DATE = '2023-10-14'; # DATE from Dist::Zilla::Plugin::OurDate
 
 use Carp;
 our @CARP_NOT = ("ODF::lpOD_Helper", "ODF::lpOD");
@@ -827,7 +827,7 @@ sub new {
       // croak "Neither proto_tag or proto_elt was specified";
     my $context = delete($opts{context}) // croak "Missing context";
     (my @r = $context->Hreplace($proto_tag, [""], %opts))
-      // croak ivis 'proto_tag $proto_tag not found';
+      || croak ivis 'proto_tag $proto_tag not found';
     $proto_elt = $r[0]->{para}->parent(TABLE_SECTION_FRAME_FILTER)
       // croak ivis 'proto_tag $proto_tag is not located in a proto container';
   }
@@ -1358,9 +1358,8 @@ L<ODF::lpOD_Helper>
 
 L<Sreadsheet::Edit>
 
-=for comment The command-line tool B<ODFedit> provides access to some
-=for comment features of ODF::MailMerge without writing Perl code.
-=for comment C<cpanm App::ODFedit> will install it.
+The command-line tool B<odfedit> (which comes with L<ODF::MailMerge>)
+provides access to many features of L<ODF::MailMerge> without writing Perl code.
 
 =head1 AUTHOR
 
